@@ -11,7 +11,7 @@ class UserCreateContract(Contract):
     username = PhoneNumberField()
     department = serializers.IntegerField(min_value=1)
     ip = serializers.IPAddressField()
-    http_referer = serializers.URLField()
+    http_referer = serializers.URLField(allow_blank=True, max_length=2048)
 
 
 class SendPasswordCreateContract(Contract):
